@@ -7,9 +7,9 @@ import deskbar.handler
 # FIXME: Waiting for python bindings of galago.
 HANDLERS = {
 	"GalagoHandler" : {
-		"name": "IM Buddies",
+		"name": "Instant Messaging (IM) Buddies",
 		"description": "Send messages to your buddies by typing their name",
-		"requirements": lambda: (False, "Waiting for python bindings of galago. Should allow to send IM by typing name."),
+		"requirements": lambda: (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Waiting for python bindings of galago. Should allow to send IM by typing name.", None),
 	}
 }
 
@@ -20,7 +20,6 @@ class GalagoMatch(deskbar.handler.Match):
 		self._email = email
 		
 	def action(self, text=None):
-		self._priority = self._priority+1
 		gnomevfs.url_show("mailto:"+self._email)
 	
 	def get_verb(self):
